/*******************************************************************************
* File Name: BOOT_n.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "BOOT_n.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 BOOT_n__PORT == 15 && ((BOOT_n__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: BOOT_n_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void BOOT_n_Write(uint8 value) 
{
    uint8 staticBits = (BOOT_n_DR & (uint8)(~BOOT_n_MASK));
    BOOT_n_DR = staticBits | ((uint8)(value << BOOT_n_SHIFT) & BOOT_n_MASK);
}


/*******************************************************************************
* Function Name: BOOT_n_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  BOOT_n_DM_STRONG     Strong Drive 
*  BOOT_n_DM_OD_HI      Open Drain, Drives High 
*  BOOT_n_DM_OD_LO      Open Drain, Drives Low 
*  BOOT_n_DM_RES_UP     Resistive Pull Up 
*  BOOT_n_DM_RES_DWN    Resistive Pull Down 
*  BOOT_n_DM_RES_UPDWN  Resistive Pull Up/Down 
*  BOOT_n_DM_DIG_HIZ    High Impedance Digital 
*  BOOT_n_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void BOOT_n_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(BOOT_n_0, mode);
}


/*******************************************************************************
* Function Name: BOOT_n_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro BOOT_n_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 BOOT_n_Read(void) 
{
    return (BOOT_n_PS & BOOT_n_MASK) >> BOOT_n_SHIFT;
}


/*******************************************************************************
* Function Name: BOOT_n_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 BOOT_n_ReadDataReg(void) 
{
    return (BOOT_n_DR & BOOT_n_MASK) >> BOOT_n_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(BOOT_n_INTSTAT) 

    /*******************************************************************************
    * Function Name: BOOT_n_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 BOOT_n_ClearInterrupt(void) 
    {
        return (BOOT_n_INTSTAT & BOOT_n_MASK) >> BOOT_n_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
